class PnWKitException(Exception):
    ...


class GraphQLError(PnWKitException):
    ...
